@@ -782,17 +782,17 @@ class FTTRU
   private :_alloc_y
 
   def f(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttruf(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
   def b(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttrub(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
 end
@@ -813,17 +813,17 @@ class FTTCT
   private :_alloc_y
 
   def f(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttctf(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
   def b(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttctb(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
 end
@@ -844,17 +844,17 @@ class FTTST
   private :_alloc_y
 
   def f(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttstf(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
   def b(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttstb(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
 end
@@ -875,17 +875,17 @@ class FTTCM
   private :_alloc_y
 
   def f(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttcmf(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
   def b(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttcmb(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
 end
@@ -906,17 +906,17 @@ class FTTSM
   private :_alloc_y
 
   def f(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttsmf(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
   def b(x)
-    raise "args must be a 3-d narray" if x.rank != 3
+    raise "args must be a 2-d narray" if x.rank != 2
     shape = x.shape
     @m = shape[0]
-    _alloc_y(@m*@n*2)
+    _alloc_y(@m*@n)
     ISPACK::fttsmb(@m,@n,x,@y,@it,@t).reshape!(*shape)
   end
 end
