@@ -5,14 +5,6 @@
 #
 # history:
 # 05/05/20 ispack_wrap.rb 
-# 05/05/23   ver.4 AP,ST,SM,SN,C2,N2,SP,NDǤǤ褦ˤʤä
-# 05/05/24   ver.5 ѿѿˤ롢̾ISPACK
-# 05/05/24   ver.6 ĹåSPPACK㳰Ū
-# 05/05/31   ver.7 LTPACKб
-# 05/05/31   ver.8 FTPACKб, SPPACKΥХ
-# 05/06/13   ver.9 ޥ˥奢Υ֥롼̾βԡ̤԰
-#                  ˤбǤ褦ˤʤä
-# 05/06/17   ver.10 C2PACKΥХ
 # 05/06/20   ver.11 Ϥ¿ʤ1롢ΰĹɬפʬְʾ
 # 05/06/24   ver.12 ̥åѡ
 # 05/07/20   ver.13 Ĺåshapetotalѹ1(ver11)ϼ
@@ -20,6 +12,7 @@
 # 05/10/03   ver.15 P2PACK,SPPACK,SOPACKθб
 # 05/10/12   ver.16 SMPACK,LTPACKΥХ
 #                   CåѡκˡѹC2SWCK,SPSWNX,SPSWHXΥХfix
+# 06/01/25 ispack_makewrapper.rb ̾FTPACKΥХ
 #-----------------------------------------------------------------------------#
 
 libfilename = "ispack_raw" # .so ˻Ȥ̾
@@ -379,6 +372,22 @@ vars1["C2G2SA"] = vars1["C2G2SA"][0..4] +
 vars["C2S2GA"]["s"] = {"type"=>"(D((2*KM+1)*LM))", "inout"=>"in"} if vars1["C2S2GA"]
 vars["C2G2SA"]["s"] = {"type"=>"(D((2*KM+1)*(LM+1)))", "inout"=>"out"} if vars1["C2G2SA"]
 
+["FTTZLI","FTTZUI","FTTRUI","FTTCTI","FTTSTI","FTTCMI","FTTSMI"].each{ |name|
+  vars[name]["it"]["inout"] = "out" if vars1[name]
+  vars[name]["t"]["inout"] = "out" if vars1[name]
+}
+
+["FTTZLM","FTTZUF","FTTZUB"].each{ |name|
+  vars[name]["x"]["type"] = "(D(M*N*2))" if vars1[name]
+  vars[name]["y"]["type"] = "(D(M*N*2))" if vars1[name]
+}
+
+["FTTRUF","FTTRUB","FTTCTF","FTTCTB","FTTSTF","FTTSTB","FTTCMF","FTTCMB","FTTSMF","FTTSMB"].each{ |name|
+  vars[name]["x"]["type"] = "(D(M*N))" if vars1[name]
+  vars[name]["y"]["type"] = "(D(M*N))" if vars1[name]
+}
+
+
 # 㳰ޤ
 
 
